%define debug_package %{nil}

Name:		bulk-reviewer
Version:	0.3.0
Release:	1%{?dist}
Summary:	bulk-reviewer aids in identification, review, and removal of sensitive files in directories and disk images

Group:		Applications/File
License:	GPL
URL:		https://github.com/bulk-reviewer/bulk-reviewer
Source0:	%{name}-%{version}.tar.gz
BuildRoot:	%(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
BuildRequires:	python3-virtualenv
BuildRequires:	npm
BuildRequires:	libewf-devel
%if 0%{?fedora} 
BuildRequires:	python3-sphinx
BuildRequires:	yarnpkg
%endif
%if 0%{?centos}
BuildRequires:	yarn
%endif
%if 0
Source1:	BulkReviewer-0.3.0.AppImage
%endif
Requires:	bulk_extractor
Requires:	sleuthkit

%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{version}}
%define  __os_install_post echo Do Nothing

%description
Bulk Reviewer is an Electron desktop application that aids in identification, review, and
removal of sensitive files in directories and disk images. Bulk Reviewer scans directories and
disk images for personally identifiable information (PII) and other sensitive information using
bulk_extractor, a best-in-class digital forensics tool. The desktop application enables users to:

  * Scan disk images and directories for private information with bulk_extractor (configurable with user-supplied regular expressions and stoplist files)
  * Review features found by type and by file in a user-friendly dashboard that supports annotation and dismissing features as false positives
  * Generate CSV reports of features found
  * Export sets of files
  * Cleared: Files free of PII
  * Private: Files with PII that should be restricted or run through redaction software

Currently, Bulk Reviewer can scan directories and disk images for:

  * Social Security Numbers (SSNs)
  * Canadian Social Insurance Number (SINs)
  * Credit card numbers
  * Email addresses
  * Phone numbers
  * vCards (Virtual Contact Files)
  * URLs, web domains, RFC822 headers, and HTTP logs
  * GPS data
  * EXIF metadata
  * User-supplied regular expressions (uploaded as a txt file with each regexp on a new line)

Scanners planned but not yet implemented include:

  * Personal names
  * Other national identifiers
  * Banking information (e.g. IBAN and SWIFT account numbers, ABA numbers)
  * Personal health information
  * Facebook and Outlook data
  * Additional lexicons (like those developed by the ePADD project team)

The application is designed to aid archivists and librarians in processing and providing access
to digital collections but may be useful in other domains as well. Bulk Reviewer has been made
possible in part by the generous support of a Harvard Library Innovation Lab summer fellowship
and a Concordia University Library Research Grant.

%prep
%setup -q

%build
%if 0%{?fedora} || 0%{?centos}
virtualenv -p python3 VE
sh -c "source VE/bin/activate; pip3 install --upgrade pip"
sh -c "source VE/bin/activate; pip3 install -r src/main/backend/requirements.txt"
sh -c "source VE/bin/activate; ./build-backend.sh"
sh -c "source VE/bin/activate; yarn install; exit 0"
sh -c "source VE/bin/activate; yarn run build"
%endif

%if 0%{?centos}
virtualenv -p python3 VE
sh -c "source VE/bin/activate; pip3 install --upgrade pip"
sh -c "source VE/bin/activate; pip3 install sphinx"
sh -c "source VE/bin/activate; cd docs; make html"
%else
cd docs
make html
%endif

%install
rm -rf $RPM_BUILD_ROOT
%{__install} -d %{buildroot}/%{_bindir}

%{__install} -m755 build/BulkReviewer-0.3.0.AppImage %{buildroot}%{_bindir}

cat > %{buildroot}%{_bindir}/%{name} << 'EOF'
#!/bin/sh

exec BulkReviewer-0.3.0.AppImage "$@"
EOF

%{__install} -d %{buildroot}/%{_pkgdocdir}
(cd docs/_build/html; tar cf - . )| (cd %{buildroot}/%{_pkgdocdir}; tar xf -)

%clean
rm -rf $RPM_BUILD_ROOT

%files
%attr(755,root,root) /usr/bin/%{name}
%attr(755,root,root) /usr/bin/BulkReviewer-0.3.0.AppImage
%doc %{_pkgdocdir}

%changelog
* Mon Oct  4 2021 Lawrence Rogers <lrr@cert.org> - 0.3.0-1
* Release 0.3.0-1
	Bulk-reviewer version 0.3.0
